==> connectagram_1.2.11.orig.tar.gz: connectagram-1.2.11/translations/connectagram_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>ChainPattern</name>
    <message>
        <source>Chain</source>
        <translation>Ketting</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>Loading</source>
        <translation>Aan het laden</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Gepauzeerd</translation>
    </message>
</context>
<context>
    <name>Definitions</name>
    <message>
        <source>Definitions</source>
        <translation>Definities</translation>
    </message>
    <message>
        <source>Downloading definition...</source>
        <translation>Definities aan het downloaden...</translation>
    </message>
    <message>
        <source>Unsolved word</source>
        <translation>Nog niet opgelost woord</translation>
    </message>
</context>
<context>
    <name>Dictionary</name>
    <message>
        <source>Definition from Wiktionary, the free dictionary</source>
        <translation>Definitie van Wiktionary, het vrije woordenboek</translation>
    </message>
    <message>
        <source>No definition found</source>
        <translation>Geen definitie gevonden</translation>
    </message>
    <message>
        <source>Unable to connect to Wiktionary</source>
        <translation>Connectie met Wiktionary niet mogelijk</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <source>Fence</source>
        <translation>Hekwerk</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selecteer de applicatie taal</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;systeem taal&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Notitie</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Herstart de applicatie om de taalwijziging door te voeren</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nieuw spel</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Laag</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medium</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Hoog</translation>
    </message>
    <message>
        <source>Very High</source>
        <translation>Zeer hoog</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Taal:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Woord lengte</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Aantal woorden:</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n letter</numerusform>
            <numerusform>%n letters</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <source>Rings</source>
        <translation>Ringen</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <source>Scores</source>
        <translation>Scores</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Score</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Tijd</translation>
    </message>
    <message>
        <source>Words</source>
        <translation>Woorden</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Lengte</translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <source>Stairs</source>
        <translation>Trappen</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <source>Twisty</source>
        <translation>Gedraaidheid</translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <source>Wave</source>
        <translation>Golf</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Success</source>
        <translation>Succes</translation>
    </message>
    <message>
        <source>Loading</source>
        <translation>Aan het laden</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Gepauzeerd</translation>
    </message>
    <message>
        <source>Definitions</source>
        <translation>Definities</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>Hint</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Spel</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Kies...</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Details</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauzeren</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Hint</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D&amp;efinitions</source>
        <translation>D&amp;efinities</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Scores</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Stoppen</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Instellingen</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Taal van de applicatie</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Over &amp;Qt</translation>
    </message>
    <message>
        <source>Choose Game</source>
        <translation>Kies Spel</translation>
    </message>
    <message>
        <source>Game Number:</source>
        <translation>Spel nummer:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Het is niet mogelijk het gevraagde spel te starten</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <source>Connectagram</source>
        <translation>Connectagram</translation>
    </message>
    <message>
        <source>A word unscrambling game</source>
        <translation>Een spel om woorden uit de knoop te halen</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1  Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Uitgegeven onder de &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</translation>
    </message>
    <message>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>Definities zijn van &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Patroon:</translation>
    </message>
    <message>
        <source>&amp;Resume</source>
        <translation>&amp;Doorgaan</translation>
    </message>
</context>
</TS>

==> connectagram_1.3.1.orig.tar.gz: connectagram-1.3.1/translations/connectagram_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>ChainPattern</name>
    <message>
        <source>Chain</source>
        <translation>Ketting</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>Loading</source>
        <translation>Aan het laden</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Gepauzeerd</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <source>Fence</source>
        <translation>Hekwerk</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selecteer de applicatie taal</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;systeem taal&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Notitie</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Herstart de applicatie om de taalwijziging door te voeren</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nieuw spel</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Laag</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medium</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Hoog</translation>
    </message>
    <message>
        <source>Very High</source>
        <translation>Zeer hoog</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Taal:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Woord lengte</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Aantal woorden:</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n letter</numerusform>
            <numerusform>%n letters</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <source>Rings</source>
        <translation>Ringen</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Score</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Tijd</translation>
    </message>
    <message>
        <source>Words</source>
        <translation>Woorden</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Lengte</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <source>Stairs</source>
        <translation>Trappen</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <source>Twisty</source>
        <translation>Gedraaidheid</translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <source>Wave</source>
        <translation>Golf</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Success</source>
        <translation>Succes</translation>
    </message>
    <message>
        <source>Loading</source>
        <translation>Aan het laden</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Gepauzeerd</translation>
    </message>
    <message>
        <source>Definitions</source>
        <translation>Definities</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>Hint</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Spel</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Kies...</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Details</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauzeren</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Hint</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D&amp;efinitions</source>
        <translation>D&amp;efinities</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Stoppen</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Instellingen</translation>
    </message>
    <message>
        <source>&amp;Dark Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Taal van de applicatie</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Over &amp;Qt</translation>
    </message>
    <message>
        <source>Choose Game</source>
        <translation>Kies Spel</translation>
    </message>
    <message>
        <source>Game Number:</source>
        <translation>Spel nummer:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Het is niet mogelijk het gevraagde spel te starten</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <source>Connectagram</source>
        <translation>Connectagram</translation>
    </message>
    <message>
        <source>A word unscrambling game</source>
        <translation>Een spel om woorden uit de knoop te halen</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1  Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Uitgegeven onder de &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</translation>
    </message>
    <message>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>Definities zijn van &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Patroon:</translation>
    </message>
</context>
</TS>
